You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@sling.apache.org by kw...@apache.org on 2018/06/10 15:02:49 UTC

[sling-org-apache-sling-servlets-annotations] branch master updated: enhance javadoc

This is an automated email from the ASF dual-hosted git repository.

kwin pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/sling-org-apache-sling-servlets-annotations.git


The following commit(s) were added to refs/heads/master by this push:
     new 9b7132c  enhance javadoc
     new 3929cd8  Merge branch 'master' of git@github.com:apache/sling-org-apache-sling-servlets-annotations.git
9b7132c is described below

commit 9b7132ca1a9b033495f537019a858bddc4afd1b4
Author: Konrad Windszus <kw...@apache.org>
AuthorDate: Sun Jun 10 17:02:10 2018 +0200

    enhance javadoc
---
 pom.xml                                                              | 5 +++++
 .../org/apache/sling/servlets/annotations/SlingServletFilter.java    | 5 +++--
 .../java/org/apache/sling/servlets/annotations/SlingServletName.java | 2 +-
 .../org/apache/sling/servlets/annotations/SlingServletPaths.java     | 2 +-
 .../apache/sling/servlets/annotations/SlingServletResourceTypes.java | 2 +-
 5 files changed, 11 insertions(+), 5 deletions(-)

diff --git a/pom.xml b/pom.xml
index 2be9ba8..bee6faf 100644
--- a/pom.xml
+++ b/pom.xml
@@ -47,6 +47,11 @@
             <version>1.4.0</version><!-- for annotation @ComponentPropertyType -->
         </dependency>
         <dependency>
+            <groupId>org.osgi</groupId>
+            <artifactId>org.osgi.service.component</artifactId>
+            <version>1.4.0</version><!-- for link in javadoc to default property types/annotations -->
+        </dependency>
+        <dependency>
             <groupId>org.apache.sling</groupId>
             <artifactId>org.apache.sling.api</artifactId>
             <!-- https://issues.apache.org/jira/browse/SLING-6249, only for link in javadoc -->
diff --git a/src/main/java/org/apache/sling/servlets/annotations/SlingServletName.java b/src/main/java/org/apache/sling/servlets/annotations/SlingServletName.java
index ef68ac8..f10ce34 100644
--- a/src/main/java/org/apache/sling/servlets/annotations/SlingServletName.java
+++ b/src/main/java/org/apache/sling/servlets/annotations/SlingServletName.java
@@ -21,7 +21,7 @@ import org.osgi.service.component.annotations.ComponentPropertyType;
 
 /**
  * Component Property Type (as defined by OSGi DS 1.4) for Sling Servlets.
- * Takes care of writing the relevant component properties to set a name for a Sling Servlet.
+ * Takes care of writing the relevant service properties to set a name for a Sling Servlet.
  * Must be combined with either {@link SlingServletResourceTypes} or {@link SlingServletPaths}.
  *
  * @see <a href="https://github.com/apache/felix/blob/trunk/tools/org.apache.felix.scr.annotations/src/main/java/org/apache/felix/scr/annotations/sling/SlingServlet.java">Felix SCR annotations</a>
diff --git a/src/main/java/org/apache/sling/servlets/annotations/SlingServletPaths.java b/src/main/java/org/apache/sling/servlets/annotations/SlingServletPaths.java
index f402b25..ab8c624 100644
--- a/src/main/java/org/apache/sling/servlets/annotations/SlingServletPaths.java
+++ b/src/main/java/org/apache/sling/servlets/annotations/SlingServletPaths.java
@@ -20,7 +20,7 @@ import org.apache.sling.api.servlets.ServletResolverConstants;
 import org.osgi.service.component.annotations.ComponentPropertyType;
 /**
  * Component Property Type (as defined by OSGi DS 1.4) for Sling Servlets.
- * Takes care of writing the relevant component properties as being used by the Sling Servlet Resolver ({@link ServletResolverConstants})
+ * Takes care of writing the relevant service properties as being used by the Sling Servlet Resolver ({@link ServletResolverConstants})
  * to register the annotated servlet component as Sling servlet for a specific path.
  * Preferably register Sling servlets by resource type ({@link SlingServletResourceTypes}) though 
  * for reasons outlined at <a href="https://sling.apache.org/documentation/the-sling-engine/servlets.html#caveats-when-binding-servlets-by-path">
diff --git a/src/main/java/org/apache/sling/servlets/annotations/SlingServletResourceTypes.java b/src/main/java/org/apache/sling/servlets/annotations/SlingServletResourceTypes.java
index 0881303..5fef52f 100644
--- a/src/main/java/org/apache/sling/servlets/annotations/SlingServletResourceTypes.java
+++ b/src/main/java/org/apache/sling/servlets/annotations/SlingServletResourceTypes.java
@@ -20,7 +20,7 @@ import org.apache.sling.api.servlets.ServletResolverConstants;
 import org.osgi.service.component.annotations.ComponentPropertyType;
 /**
  * Component Property Type (as defined by OSGi DS 1.4) for Sling Servlets.
- * Takes care of writing the relevant component properties as being used by the Sling Servlet Resolver ({@link ServletResolverConstants})
+ * Takes care of writing the relevant service properties as being used by the Sling Servlet Resolver ({@link ServletResolverConstants})
  * to register the annotated servlet component as Sling servlet for a specific resource type.
  * 
  * @see <a href="https://sling.apache.org/documentation/the-sling-engine/servlets.html">Sling Servlets</a>

diff --git a/src/main/java/org/apache/sling/servlets/annotations/SlingServletFilter.java b/src/main/java/org/apache/sling/servlets/annotations/SlingServletFilter.java
index de6fbb6..bb961d9 100644
--- a/src/main/java/org/apache/sling/servlets/annotations/SlingServletFilter.java
+++ b/src/main/java/org/apache/sling/servlets/annotations/SlingServletFilter.java
@@ -18,14 +18,15 @@ package org.apache.sling.servlets.annotations;
 
 import org.apache.sling.api.servlets.ServletResolverConstants;
 import org.osgi.service.component.annotations.ComponentPropertyType;
+import org.osgi.service.component.propertytypes.ServiceRanking;
 
 /** 
  * Component Property Type (as defined by OSGi DS 1.4) for Sling Servlet Filters. 
  * Takes care of writing the relevant component properties as being used by the Sling Servlet Resolver 
  * ({@link ServletResolverConstants}) to register the annotated servlet filter component as
  * Sling servlet filter. 
  * <br><br>
  * The order of the filter is determined by the property {@code service.ranking}. Its value is used to sort the filters. 
  * Filters with a higher order are executed before a filter with a lower order. If two filters have the same order, 
  * the one with the lower service id is executed first.
  * <br>
@@ -18,14 +18,15 @@ package org.apache.sling.servlets.annotations;
 /** 
  * Component Property Type (as defined by OSGi DS 1.4) for Sling Servlet Filters. 
- * Takes care of writing the relevant component properties as being used by the Sling Servlet Resolver 
+ * Takes care of writing the relevant service properties as being used by the Sling Servlet Resolver 
  * ({@link ServletResolverConstants}) to register the annotated servlet filter component as
  * Sling servlet filter. 
@@ -18,14 +18,15 @@ package org.apache.sling.servlets.annotations;
  * Sling servlet filter. 
  * <br><br>
- * The order of the filter is determined by the property {@code service.ranking}. Its value is used to sort the filters. 
+ * The order of the filter is determined by the property {@code service.ranking}. To set it use the annotation {@link ServiceRanking}. Its value is used to sort the filters. 
  * Filters with a higher order are executed before a filter with a lower order. If two filters have the same order, 
  * the one with the lower service id is executed first.
-- 
To stop receiving notification emails like this one, please contact
kwin@apache.org.